@@ -12,8 +12,15 @@ class ValidationError(Exception):
 
 class Validations:
     def acceptable_label(self, label):
-        if label not in ["init", "install", "npm", "start", "build"]:
-
+        if label not in [
+            "init",
+            "install",
+            "npm",
+            "start",
+            "build",
+            "check-updates",
+            "update",
+        ]:
             raise ValidationError(f"Subcommand {label} doesn't exist")
 
     def is_installed(self, app_name):
